Re-exports
Modules
Macros
- rumtk_
web_ api_ process - rumtk_
web_ collect_ page - rumtk_
web_ compile_ css_ bundle - rumtk_
web_ fetch - rumtk_
web_ generate_ job_ id - rumtk_
web_ get_ api_ endpoint - rumtk_
web_ get_ component - rumtk_
web_ get_ config - Get field state from the configuration section of the SharedAppState object. The configuration is of type AppConf.
- rumtk_
web_ get_ config_ section - Retrieve a configuration (AppConf) item. These are strings driven by the app designer’s generated configuration. Unlike rumtk_web_get_config_string, the item retrieved here is separate from the strings section.
- rumtk_
web_ get_ config_ string - Retrieve a configuration (AppConf) static string. These are strings driven by the app designer’s generated configuration.
- rumtk_
web_ get_ default_ page - Returns the default page function that can be used for rendering that page
- rumtk_
web_ get_ form - This is an API macro to get the list of rendered elements that will be fed into the form shell to render your form in your web page.
- rumtk_
web_ get_ job_ manager - rumtk_
web_ get_ page - Helper function for retrieving pages registered in the global cache using a string key!
- rumtk_
web_ get_ param - rumtk_
web_ get_ param_ eq - rumtk_
web_ get_ text_ item - rumtk_
web_ init_ api_ endpoints - rumtk_
web_ init_ components - rumtk_
web_ init_ forms - This is an API macro for defining a form that can be used to render it later in your web pages.
- rumtk_
web_ init_ job_ manager - rumtk_
web_ init_ pages - Registers a set of pages provided by the user.
- rumtk_
web_ load_ conf - Load the configuration for this app at the specified path. By default, we look into
./app.jsonas the location of the configuration. - rumtk_
web_ modify_ state - Facility for modifying the state in an instance of SharedAppState.
- rumtk_
web_ params_ map - rumtk_
web_ register_ api - rumtk_
web_ register_ app_ components - Convenience macro for quickly building the AppComponents object. Feel free to pass an instance of AppComponents directly to [run_app] or rumtk_web_run_app.
- rumtk_
web_ register_ app_ switches - Convenience macro for generating a AppSwitches instance containing the boolean options a framework consumer would like to opt-in.
- rumtk_
web_ register_ component - rumtk_
web_ register_ page - rumtk_
web_ render_ component - Render component into an HTML Response Body of type HTMLResult. This macro is a bit more complex. Depending on the arguments passed to it, it can
- rumtk_
web_ render_ html - rumtk_
web_ render_ markdown - If using raw strings, do not leave an extra line. The first input must have characters, or you
will get
blocks regardless of what you do. - rumtk_
web_ render_ page_ contents - Generates the HTML page as prescribed by the input
pagefunction of type HTMLResult. - rumtk_
web_ render_ redirect - Generate redirect response automatically instead of actually rendering an HTML page.
- rumtk_
web_ run_ app - This is the main macro for defining your applet and launching it. Usage is very simple and the only decision from a user is whether to pass a list of UserPages or a list of UserPages and a list of UserComponents.
- rumtk_
web_ save_ conf - Serializes AppConf default contents and saves it to a file on disk at a specified path or relative to the current working directory. This is done to pre-craft a default configuration skeleton so a consumer of the framework can simply update that file before testing and shipping to production.
- rumtk_
web_ set_ config - Set field or state in the configuration section of the SharedAppState object. The configuration is of type AppConf.