pub struct GotoButton { /* private fields */ }Trait Implementations
Sourceimpl Clone for GotoButton
impl Clone for GotoButton
Sourcefn clone(&self) -> GotoButton
fn clone(&self) -> GotoButton
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GotoButton
impl Debug for GotoButton
Sourceimpl Display for GotoButton
Implement the format!() trait for GotoButton
impl Display for GotoButton
Implement the format!() trait for GotoButton
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for GotoButton
impl FastWritable for GotoButton
impl HtmlSafe for GotoButton
Sourceimpl Template for GotoButton
impl Template for GotoButton
Sourceconst SIZE_HINT: usize = 199usize
const SIZE_HINT: usize = 199usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for GotoButton
impl RefUnwindSafe for GotoButton
impl Send for GotoButton
impl Sync for GotoButton
impl Unpin for GotoButton
impl UnsafeUnpin for GotoButton
impl UnwindSafe for GotoButton