pub struct InputElement<'a> { /* private fields */ }Trait Implementations
Sourceimpl<'a> Clone for InputElement<'a>
impl<'a> Clone for InputElement<'a>
Sourcefn clone(&self) -> InputElement<'a>
fn clone(&self) -> InputElement<'a>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for InputElement<'a>
impl<'a> Debug for InputElement<'a>
Sourceimpl<'a> Display for InputElement<'a>
Implement the format!() trait for InputElement
impl<'a> Display for InputElement<'a>
Implement the format!() trait for InputElement
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl<'a> FastWritable for InputElement<'a>
impl<'a> FastWritable for InputElement<'a>
Sourcefn write_into<AskamaW>(
&self,
dest: &mut AskamaW,
values: &dyn Values,
) -> Result<()>
fn write_into<AskamaW>( &self, dest: &mut AskamaW, values: &dyn Values, ) -> Result<()>
Used internally by askama to speed up writing some types.
Sourceimpl<'a> Template for InputElement<'a>
impl<'a> Template for InputElement<'a>
Sourceconst SIZE_HINT: usize = 44usize
const SIZE_HINT: usize = 44usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values<AskamaW>(
&self,
__askama_writer: &mut AskamaW,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values<AskamaW>( &self, __askama_writer: &mut AskamaW, __askama_values: &dyn Values, ) -> Result<()>
Renders the template to the given
writer fmt buffer with provided Values.Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it.Sourcefn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
fn render_with_values(&self, values: &dyn Values) -> Result<String, Error>
Helper method which allocates a new
String and renders into it with provided Values.Sourcefn render_into<W>(&self, writer: &mut W) -> Result<(), Error>
fn render_into<W>(&self, writer: &mut W) -> Result<(), Error>
Renders the template to the given
writer fmt buffer.Auto Trait Implementations
impl<'a> Freeze for InputElement<'a>
impl<'a> RefUnwindSafe for InputElement<'a>
impl<'a> Send for InputElement<'a>
impl<'a> Sync for InputElement<'a>
impl<'a> Unpin for InputElement<'a>
impl<'a> UnsafeUnpin for InputElement<'a>
impl<'a> UnwindSafe for InputElement<'a>