pub struct FormattedLabel { /* private fields */ }Trait Implementations
Sourceimpl Clone for FormattedLabel
impl Clone for FormattedLabel
Sourcefn clone(&self) -> FormattedLabel
fn clone(&self) -> FormattedLabel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormattedLabel
impl Debug for FormattedLabel
Sourceimpl Display for FormattedLabel
Implement the format!() trait for FormattedLabel
impl Display for FormattedLabel
Implement the format!() trait for FormattedLabel
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for FormattedLabel
impl FastWritable for FormattedLabel
impl HtmlSafe for FormattedLabel
Sourceimpl Template for FormattedLabel
impl Template for FormattedLabel
Sourceconst SIZE_HINT: usize = 178usize
const SIZE_HINT: usize = 178usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for FormattedLabel
impl RefUnwindSafe for FormattedLabel
impl Send for FormattedLabel
impl Sync for FormattedLabel
impl Unpin for FormattedLabel
impl UnsafeUnpin for FormattedLabel
impl UnwindSafe for FormattedLabel