pub struct Header<T: RUMWebTemplate> { /* private fields */ }Trait Implementations
Sourceimpl<T: RUMWebTemplate> Display for Header<T>
impl<T: RUMWebTemplate> Display for Header<T>
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl<T: RUMWebTemplate> FastWritable for Header<T>
impl<T: RUMWebTemplate> FastWritable for Header<T>
impl<T: RUMWebTemplate + RUMWebTemplateSafe> HtmlSafe for Header<T>
Sourceimpl<T: RUMWebTemplate> Template for Header<T>
impl<T: RUMWebTemplate> Template for Header<T>
Sourceconst SIZE_HINT: usize = 183usize
const SIZE_HINT: usize = 183usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl<T> Freeze for Header<T>where
T: Freeze,
impl<T> RefUnwindSafe for Header<T>where
T: RefUnwindSafe,
impl<T> Send for Header<T>where
T: Send,
impl<T> Sync for Header<T>where
T: Sync,
impl<T> Unpin for Header<T>where
T: Unpin,
impl<T> UnsafeUnpin for Header<T>where
T: UnsafeUnpin,
impl<T> UnwindSafe for Header<T>where
T: UnwindSafe,