pub struct PortraitCard { /* private fields */ }Trait Implementations
Sourceimpl Debug for PortraitCard
impl Debug for PortraitCard
Sourceimpl Display for PortraitCard
Implement the format!() trait for PortraitCard
impl Display for PortraitCard
Implement the format!() trait for PortraitCard
Please be aware of the rendering performance notice in the Template trait.
Sourceimpl FastWritable for PortraitCard
impl FastWritable for PortraitCard
impl HtmlSafe for PortraitCard
Sourceimpl Template for PortraitCard
impl Template for PortraitCard
Sourceconst SIZE_HINT: usize = 845usize
const SIZE_HINT: usize = 845usize
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourcefn render_into_with_values(
&self,
__askama_writer: &mut dyn Write,
__askama_values: &dyn Values,
) -> Result<()>
fn render_into_with_values( &self, __askama_writer: &mut dyn Write, __askama_values: &dyn Values, ) -> Result<()>
Sourcefn render(&self) -> Result<String, Error>
fn render(&self) -> Result<String, Error>
Helper method which allocates a new
String and renders into it. Read moreSourcefn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
fn render_into(&self, writer: &mut dyn Write) -> Result<(), Error>
Renders the template to the given
writer fmt buffer. Read moreAuto Trait Implementations
impl Freeze for PortraitCard
impl RefUnwindSafe for PortraitCard
impl Send for PortraitCard
impl Sync for PortraitCard
impl Unpin for PortraitCard
impl UnsafeUnpin for PortraitCard
impl UnwindSafe for PortraitCard