Module app

Module app 

Structs

AppComponents
Struct encapsulating custom-made items to register with the framework.
AppSwitches
Struct for defining the global switches to drive the initialization of the web app. This struct works hand in hand with AppComponents.

Functions

app_main
Main API function for running and serving the web application.