Module conf

Module conf 

Macros

rumtk_create_const_ordered_map

Structs

AppConf
This is a core structure in a web project using the RUMTK framework. This structure contains a series of fields that represent the web app initial state or configuration. The idea is that the web app can come bundled with a JSON config file following this structure which we can load at runtime. The settings will dictate a few key project behaviors such as properly labeling some components with the company name or use the correct language text.
AppState
Main internal structure for holding the initial app configuration (AppConf), the clipboard containing dynamically generated state (NestedTextMap), and the jobs field containing
CORSConf
FlagsConf
FooterConf
HeaderConf
PageConf
PipelineConf
RouterConf

Type Aliases

ClipboardID
PageMap
RouterAppState
SharedAppState