Module render

Module render 

Statics

MARKDOWN_OPTIONS
MARKDOWN_OPTIONS_INIT

Functions

rumtk_web_redirect
rumtk_web_render_contents
rumtk_web_render_html
Render the given component template into an HTML Body response or a URL Redirect response. If you provide the RUMWebRedirect in the url parameter configured for redirection, then we return the redirection as the response. Otherwise, we render the HTML and save it in the response.
rumtk_web_trim_rendered_html
This function trims excess newlines and whitespacing outside tag block (e.g. <div></div>). The idea is to cleanup the rendered template which picks up extra characters due to the way string literals work in proc macros.