Module types

Module types 

Re-exports

pub use crate::utils::form_data::FormBuffer;
pub use crate::utils::form_data::FormData;
pub use super::conf::*;
pub use crate::utils::response::*;

Structs

RUMWebDataProxy

Traits

AsStr
CompactStringExt
A trait that provides convenience methods for creating a CompactString from a collection of items. It is implemented for all types that can be converted into an iterator, and that iterator yields types that can be converted into a str.
RUMStringConversions
RUMWebTemplate
Main Template trait; implementations are generally derived
StringLike

Type Aliases

APIFunction
APIPath
AsyncURLParams
AsyncURLPath
ComponentFunction
ComponentMap
PageFunction
PageMap
RUMString
RUMWebData
RenderedPageComponents
RenderedPageComponentsResult
RouterAPIPath
RouterComponents
RouterForm
RouterParams
URLParams
URLPath

Derive Macros

RUMWebTemplate
The Template derive macro and its template() attribute.