pub trait RUMWebTemplateSafe: Display { }Expand description
Types that implement this marker trait don’t need to be HTML escaped
Please note that this trait is only meant as speed-up helper. In some odd circumcises askama
might still decide to HTML escape the input, so if this must not happen, then you need to use
the |safe filter to prevent the auto escaping.
If you are unsure if your type generates HTML safe output in all cases, then DON’T mark it. Better safe than sorry!
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl HtmlSafe for NonZero<i8>
impl HtmlSafe for NonZero<i16>
impl HtmlSafe for NonZero<i32>
impl HtmlSafe for NonZero<i64>
impl HtmlSafe for NonZero<i128>
impl HtmlSafe for NonZero<isize>
impl HtmlSafe for NonZero<u8>
impl HtmlSafe for NonZero<u16>
impl HtmlSafe for NonZero<u32>
impl HtmlSafe for NonZero<u64>
impl HtmlSafe for NonZero<u128>
impl HtmlSafe for NonZero<usize>
impl HtmlSafe for bool
impl HtmlSafe for f32
impl HtmlSafe for f64
impl HtmlSafe for i8
impl HtmlSafe for i16
impl HtmlSafe for i32
impl HtmlSafe for i64
impl HtmlSafe for i128
impl HtmlSafe for isize
impl HtmlSafe for u8
impl HtmlSafe for u16
impl HtmlSafe for u32
impl HtmlSafe for u64
impl HtmlSafe for u128
impl HtmlSafe for usize
impl<T> HtmlSafe for &T
impl<T> HtmlSafe for &mut T
impl<T> HtmlSafe for Arc<T>
impl<T> HtmlSafe for Box<T>
impl<T> HtmlSafe for Cow<'_, T>
Available on crate feature
alloc only.