Crate rumtk_web

Crate rumtk_web 

Re-exports

pub use app::*;
pub use utils::*;

Modules

api
components
css
pages
static_components
utils

Macros

rumtk_web_api_process
rumtk_web_collect_page
rumtk_web_compile_css_bundle
rumtk_web_fetch
rumtk_web_generate_job_id
rumtk_web_get_api_endpoint
rumtk_web_get_component
rumtk_web_get_config
Get field state from the configuration section of the SharedAppState object. The configuration is of type AppConf.
rumtk_web_get_config_section
Retrieve a configuration (AppConf) item. These are strings driven by the app designer’s generated configuration. Unlike rumtk_web_get_config_string, the item retrieved here is separate from the strings section.
rumtk_web_get_config_string
Retrieve a configuration (AppConf) static string. These are strings driven by the app designer’s generated configuration.
rumtk_web_get_default_page
Returns the default page function that can be used for rendering that page
rumtk_web_get_form
This is an API macro to get the list of rendered elements that will be fed into the form shell to render your form in your web page.
rumtk_web_get_job_manager
rumtk_web_get_page
Helper function for retrieving pages registered in the global cache using a string key!
rumtk_web_get_param
rumtk_web_get_param_eq
rumtk_web_get_text_item
rumtk_web_init_api_endpoints
rumtk_web_init_components
rumtk_web_init_forms
This is an API macro for defining a form that can be used to render it later in your web pages.
rumtk_web_init_job_manager
rumtk_web_init_pages
Registers a set of pages provided by the user.
rumtk_web_load_conf
Load the configuration for this app at the specified path. By default, we look into ./app.json as the location of the configuration.
rumtk_web_modify_state
Facility for modifying the state in an instance of SharedAppState.
rumtk_web_params_map
rumtk_web_register_api
rumtk_web_register_app_components
Convenience macro for quickly building the AppComponents object. Feel free to pass an instance of AppComponents directly to [run_app] or rumtk_web_run_app.
rumtk_web_register_app_switches
Convenience macro for generating a AppSwitches instance containing the boolean options a framework consumer would like to opt-in.
rumtk_web_register_component
rumtk_web_register_page
rumtk_web_render_component
Render component into an HTML Response Body of type HTMLResult. This macro is a bit more complex. Depending on the arguments passed to it, it can
rumtk_web_render_html
rumtk_web_render_markdown
If using raw strings, do not leave an extra line. The first input must have characters, or you will get
 blocks regardless of what you do.
rumtk_web_render_page_contents
Generates the HTML page as prescribed by the input page function of type HTMLResult.
rumtk_web_render_redirect
Generate redirect response automatically instead of actually rendering an HTML page.
rumtk_web_run_app
This is the main macro for defining your applet and launching it. Usage is very simple and the only decision from a user is whether to pass a list of UserPages or a list of UserPages and a list of UserComponents.
rumtk_web_save_conf
Serializes AppConf default contents and saves it to a file on disk at a specified path or relative to the current working directory. This is done to pre-craft a default configuration skeleton so a consumer of the framework can simply update that file before testing and shipping to production.
rumtk_web_set_config
Set field or state in the configuration section of the SharedAppState object. The configuration is of type AppConf.