macro_rules! rumtk_web_register_app_switches {
( ) => { ... };
( $skip_serve:expr ) => { ... };
( $skip_serve:expr, $skip_default_css:expr ) => { ... };
}Expand description
Convenience macro for generating a AppSwitches instance containing the boolean options a framework consumer would like to opt-in.
Examples
use rumtk_web::AppSwitches;
use rumtk_web::{rumtk_web_register_app_switches};
let expected = AppSwitches {
skip_serve: true,
skip_default_css: false
};
let switches = rumtk_web_register_app_switches!(true);
assert_eq!(switches, expected, "The switches constructed to config app does not match the expected.");