Re-exports
pub use crate::utils::form_data::FormBuffer;pub use crate::utils::form_data::FormData;pub use super::conf::*;pub use crate::utils::response::*;
Structs
Traits
- AsStr
- Compact
String Ext - A trait that provides convenience methods for creating a
CompactStringfrom a collection of items. It is implemented for all types that can be converted into an iterator, and that iterator yields types that can be converted into astr. - RUMString
Conversions - RUMWeb
Template - Main
Templatetrait; implementations are generally derived - String
Like
Type Aliases
- APIFunction
- APIPath
- AsyncURL
Params - AsyncURL
Path - Component
Function - Component
Map - Page
Function - PageMap
- RUMString
- RUMWeb
Data - Rendered
Page Components - Rendered
Page Components Result - RouterAPI
Path - Router
Components - Router
Form - Router
Params - URLParams
- URLPath
Derive Macros
- RUMWeb
Template - The
Templatederive macro and itstemplate()attribute.